@@ -2326,9 +2326,9 @@ void qh_option(qhT* qh, const char* option, int* i, realT* r) {
 
   snprintf(buf, sizeof(buf), "  %s", option);
   if(i)
-    snprintf(buf + strlen(buf), sizeof(buf), " %d", *i);
+    snprintf(buf + strlen(buf), sizeof(buf) - strlen(buf), " %d", *i);
   if(r)
-    snprintf(buf + strlen(buf), sizeof(buf), " %2.2g", *r);
+    snprintf(buf + strlen(buf), sizeof(buf) - strlen(buf), " %2.2g", *r);
   len = (int)strlen(buf); /* WARN64 */
   qh->qhull_optionlen += len;
   maxlen = sizeof(qh->qhull_options) - len - 1;
